@@ -116,6 +116,9 @@ Please visit AnkiWeb, upgrade your deck, then try again."""))
             if m:
                 self.label = m
                 self._updateLabel()
+        elif evt == "syncMsg":
+            self.label = args[0]
+            self._updateLabel()
         elif evt == "error":
             self._didError = True
             showText(_("Syncing failed:\n%s")%
@@ -181,7 +184,9 @@ AnkiWeb is too busy at the moment. Please try again in a few minutes.""")
         elif "code: 413" in err:
             return _("Your collection or a media file is too large to sync.")
         elif "EOF occurred in violation of protocol" in err:
-            return _("Error establishing a secure connection. This is usually caused by filtering software, or problems with your ISP.")
+            return _("Error establishing a secure connection. This is usually caused by antivirus, firewall or VPN software, or problems with your ISP.")
+        elif "certificate verify failed" in err:
+            return _("Error establishing a secure connection. This is usually caused by antivirus, firewall or VPN software, or problems with your ISP.")
         return err
 
     def _getUserPass(self):
@@ -296,6 +301,8 @@ class SyncThread(QThread):
         self.byteUpdate = time.time()
         def syncEvent(type):
             self.fireEvent("sync", type)
+        def syncMsg(msg):
+            self.fireEvent("syncMsg", msg)
         def canPost():
             if (time.time() - self.byteUpdate) > 0.1:
                 self.byteUpdate = time.time()
@@ -309,6 +316,7 @@ class SyncThread(QThread):
             if canPost():
                 self.fireEvent("recv", self.recvTotal)
         addHook("sync", syncEvent)
+        addHook("syncMsg", syncMsg)
         addHook("httpSend", sendEvent)
         addHook("httpRecv", recvEvent)
         # run sync and catch any errors
@@ -323,6 +331,7 @@ class SyncThread(QThread):
             # don't bump mod time unless we explicitly save
             self.col.close(save=False)
             remHook("sync", syncEvent)
+            remHook("syncMsg", syncMsg)
             remHook("httpSend", sendEvent)
             remHook("httpRecv", recvEvent)
 
